package com.ether;

import com.ether.annotation.ControllerMethod;
import com.ether.annotation.Mandatory;
import com.ether.annotation.ParamName;
import com.ether.annotation.UseJSON;
import com.ether.tapas.Observatory;
import com.ether.tapas.Tapas;
import com.ether.user.UserRole;
import net.sf.json.JSONObject;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author vmipsl
 * @date 02 march 2012
 */
public class Controller
        extends ControllerEther
{

    /** *********************************************************** **/
    /** *********************** VIEWS ***************************** **/
    /** *********************************************************** **/
    //@ControllerMethod(view = VIEW_FORM_TAPAS, loginMandatory = true, defaultView = VIEW_INDEX)
    @ControllerMethod(view = VIEW_FORM_TAPAS, loginMandatory = false, defaultView = VIEW_INDEX)
    public JSONObject viewForm()
            throws WebException
    {

        try
        {
            final List<Observatory> allObservatories = getTapasService().getAllObservatories();

            final JSONObject jsonObject = new JSONObject();
            jsonObject.put( "jSonFileFormats", getJSONFileFormat() );
            jsonObject.put( "jSonYesNos", getJSONYesNo() );
            jsonObject.put( "jSonObservatories", allObservatories );
            return jsonObject;
        }
        catch( ServiceException e )
        {
            throw new WebException( WebException.WebCode.ERROR_NO_OBSERVATORY_FOUND, e );
        }

    }





    /** *********************************************************** **/
    /** *********************** CALLS ***************************** **/
    /** *********************************************************** **/
    @ControllerMethod(jsonResult = true)
    public JSONObject createUserRequest( @ParamName("jsonTapas") @Mandatory @UseJSON final Tapas javaTapas )
            throws WebException
    {
        if( null == javaTapas )
            throw new WebException( WebException.WebCode.ERROR_JSON_TAPAS_IS_NULL, "Serialization error : jsonTapas is null", WebException.getExceptionThrowable() );

        //appel a createxml
        getTapasService().createXMLRequest( javaTapas );

        final JSONObject result = new JSONObject();
        result.put( "result", "SUCCESS" );
        return result;
    }

    private List<JSONObject> getJSONFileFormat()
    {
        final FileFormat[] fileFormats = FileFormat.values();

        final List<JSONObject> jsonFileFormats = new ArrayList<JSONObject>( fileFormats.length );

        for( final FileFormat fileFormat : fileFormats )
        {
            final JSONObject jsonFileFormat = new JSONObject();
            jsonFileFormat .put( "text", fileFormat.name() );
            jsonFileFormat .put( "value", fileFormat.name() );
            jsonFileFormats.add( jsonFileFormat  );
        }
        return jsonFileFormats;
    }

    private List<JSONObject> getJSONYesNo()
    {
        final YesNo[] yesNos = YesNo.values();

        final List<JSONObject> jsonYesNos = new ArrayList<JSONObject>( yesNos.length );

        for( final YesNo yesNo : yesNos )
        {
            final JSONObject jsonYesNo = new JSONObject();
            jsonYesNo .put( "text", yesNo.name() );
            jsonYesNo .put( "value", yesNo.name() );
            jsonYesNos.add( jsonYesNo );
        }
        return jsonYesNos;
    }

    private static final Log LOGGER = LogFactory.getLog( Controller.class );

    private static final String VIEW_INDEX = "init";
    private static final String VIEW_FORM_TAPAS = "project/formTapas";
}